@@ -430,6 +430,13 @@ WEBKIT_API void
 webkit_settings_set_enable_mediasource                         (WebKitSettings *settings,
                                                                 gboolean        enabled);
 
+WEBKIT_API gboolean
+webkit_settings_get_enable_encrypted_media                     (WebKitSettings *settings);
+
+WEBKIT_API void
+webkit_settings_set_enable_encrypted_media                     (WebKitSettings *settings,
+                                                                gboolean        enabled);
+
 WEBKIT_API gboolean
 webkit_settings_get_allow_file_access_from_file_urls           (WebKitSettings *settings);
 
@@ -451,6 +458,12 @@ WEBKIT_API void
 webkit_settings_set_hardware_acceleration_policy               (WebKitSettings *settings,
                                                                 WebKitHardwareAccelerationPolicy policy);
 
+WEBKIT_API guint32
+webkit_settings_font_size_to_points                            (guint32 pixels);
+
+WEBKIT_API guint32
+webkit_settings_font_size_to_pixels                            (guint32 points);
+
 G_END_DECLS
 
 #endif /* WebKitSettings_h */
